tooltip: Tooltip for plot Tooltip, which means that when the mouse...

Description Usage Arguments

View source: R/tooltip.R

Description

Tooltip for plot Tooltip, which means that when the mouse hovers over the chart or the finger clicks on a data point of the mobile device, the data of the point is displayed in the form of interactive prompt information, such as the value of the point, the data unit, etc.

Usage

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
tooltip(
  gWidget,
  title = NULL,
  fields = c(NULL, NULL),
  formatter = NULL,
  follow = TRUE,
  enterable = FALSE,
  showTitle = NULL,
  position = c("top", "bottom", "left", "right"),
  shared = NULL,
  showCrosshairs = FALSE,
  crosshairs = NULL,
  textStyle = NULL,
  textBackgroundStyle = NULL,
  showMarkers = TRUE,
  marker = NULL,
  showContent = NULL,
  container = NULL,
  containerTp,
  itemTpl,
  domStyles,
  offset,
  customContent
)

Arguments

customContent

GOUYONGCHAO/g2plot documentation built on March 31, 2021, 1:49 p.m.